@@ -110,6 +110,12 @@ void eclipticToJ2000(double beta, double lambda, double *rA, double *dec)
   *dec = asin(sin(beta)*cos(EPS) + cos(beta)*sin(EPS)*sin(lambda));
 }
 
+void j2000ToEcliptic(double rA, double dec, double *beta, double *lambda)
+{
+  *lambda = atan2(sin(rA)*cos(EPS) + tan(dec)*sin(EPS), cos(rA));
+  *beta   = asin(sin(dec)*cos(EPS) - cos(dec)*sin(EPS)*sin(rA));
+}
+
 /*
   Put an angle in degrees within the range of 0 -> 360 by.
 */
@@ -165,15 +171,6 @@ void getMoonPosition(double tJD, double sunELong, double *rA, double *dec, doubl
   *eLat = moonELat = asin(sin((lDoublePrime - NPrime)*DEGREES_TO_RADIANS)*8.96834418471e-2);
   eclipticToJ2000(moonELat, moonELong, rA, dec);
   *F = 0.5*(1.0 - cos(lDoublePrime*DEGREES_TO_RADIANS - sunELong));
-  /*
-  printf("D = %f, Sun long = %f, M = %f, l = %f, Mm = %f, N = %f\n",
-	 D, sunELong/DEGREES_TO_RADIANS, M, l, Mm, N);
-  printf("Enu = %f, Ae = %f, A3 = %f, Mm' = %f, Ec = %f, A4 = %f, l' = %f\n",
-	 Enu, Ae, A3, MmPrime, Ec, A4, lPrime);
-  printf("V = %f, l\" = %f, N' = %f, x = %f, y = %f, rat = %f\n",
-	 V, lDoublePrime, NPrime, x, y, rat);
-  printf("Moon Ecl Coor: (%f, %f)\n", moonELat, moonELong);
-  */
 }
 
 /*
@@ -258,7 +255,7 @@ double getTJD(int year, int month, int day, double hour)
 }
 
 /*
-  Calculate a planet's position using the metheod described in reference 1.
+  Calculate a planet's position using the method described in reference 1.
 */
 void calculatePlanetPosition(int planet, double tJD,
 			     double *eX, double *eY, double *eZ)
